#ifndef NT2_INCLUDE_FUNCTIONS_NELDERMEAD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NELDERMEAD_HPP_INCLUDED

#include <nt2/optimization/include/functions/neldermead.hpp>

#endif
